#
# spec file for package elinks
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%bcond_without js
%else
%bcond_with js
%endif
Name:           elinks
Version:        0.18.0
Release:        2.2
Summary:        An advanced and well-established feature-rich text mode web browser
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Browsers
URL:            http://elinks.or.cz/
Source0:        https://github.com/rkd77/elinks/releases/download/v%{version}/elinks-%{version}.tar.xz
Patch1:         move_ruby_headers.patch
BuildRequires:  gcc-c++
BuildRequires:  gpm-devel
%if %{with js}
BuildRequires:  pkgconfig(libcss) >= 0.9.2
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libdom)
BuildRequires:  pkgconfig(libxml++-5.0)
BuildRequires:  pkgconfig(mujs)
BuildRequires:  pkgconfig(sqlite3)
%endif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  krb5-devel
BuildRequires:  libbz2-devel
BuildRequires:  libexpat-devel
BuildRequires:  libidn2-devel
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  ruby-devel
BuildRequires:  tre-devel
BuildRequires:  zlib-devel
%ifarch ppc64le
BuildRequires:  pkgconfig(lua)
%else
BuildRequires:  pkgconfig(luajit)
%endif
Provides:       web_browser
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%perl_requires
%requires_eq    perl

%description
ELinks is an advanced and well-established feature-rich text mode web
(HTTP/FTP/..) browser. ELinks can render both frames and tables, is highly
customizable and can be extended via Lua or Guile scripts. It is very portable
and runs on a variety of platforms. Check the about page for a more complete
description.

%prep
%autosetup -n %{name}-%{version} -p1
# Remove build time references so build-compare can do its work
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/vernum.c
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" src/vernum.c

%build
# required for ruby patch
sh ./autogen.sh
export CFLAGS="%{optflags} -fno-strict-aliasing -std=gnu11"
%configure \
    --sysconfdir=%{_sysconfdir}/elinks \
    --enable-bittorrent \
    --enable-cgi \
    --enable-finger \
    --disable-fsp \
    --enable-gopher \
    --enable-nntp \
    --disable-smb \
    --enable-88-colors \
    --enable-256-colors \
    --enable-true-color \
    --enable-gemini \
    --enable-exmode \
    --enable-html-highlight \
    --enable-fastmem \
    --with-xterm \
%if %{without js}
    --without-mujs \
%else
    --with-mujs \
%endif
    --without-lzma \
    --with-gssapi \
    --without-guile \
    --with-perl \
    --without-python \
%ifarch ppc64le
    --with-luapkg=lua \
%else
    --with-luapkg=luajit \
%endif
    --with-ruby \
    --without-gnutls \
    --without-x
# Makefile is not parallel-safe
make MAKE_COLOR= V=1

%install
%make_install

# Remove unneeded file
rm -f %{buildroot}%{_datadir}/locale/locale.alias

%find_lang %{name}

# Install documentation
%define _pkgdocdir %{buildroot}%{_docdir}/%{name}
install -Dd -m 0755 %{_pkgdocdir}
install -pm 0644 AUTHORS BUGS COPYING ChangeLog NEWS SITES THANKS TODO features.conf %{_pkgdocdir}
cp -a doc/ %{_pkgdocdir}
rm -rf %{_pkgdocdir}/doc/{.deps/,.gitignore,Doxyfile.in,Makefile,man/,tools/}
install -Dd -m 0755 %{_pkgdocdir}/contrib/
install -pm 0644 contrib/*.conf contrib/*.vim contrib/*.css contrib/TIPS-AND-TRICKS %{_pkgdocdir}/contrib/
install -Dd -m 0755 %{_pkgdocdir}/scripts/
install -pm 0644 contrib/wipe-out-ssl* contrib/conv/* %{_pkgdocdir}/scripts/
rm -f %{_pkgdocdir}/scripts/conv/.gitignore
# Install only the languages that are compiled
for lang in lua perl smjs ruby; do
  install -Dd -m 0755 %{_pkgdocdir}/${lang}
  install -pm 0644 contrib/${lang}/* %{_pkgdocdir}/${lang}
done
rm -f %{_pkgdocdir}/lua/.gitignore

%files -f %{name}.lang
%defattr(-,root,root,-)
%{_bindir}/%{name}
%doc %{_docdir}/%{name}/
%{_mandir}/man1/%{name}.1%{ext_man}
%{_mandir}/man5/%{name}*.5%{ext_man}

%changelog
* Sun Apr 13 2025 Friedrich Haubensak <hsk17@mail.de>
- add -std=gnu11 to CFLAGS to fix gcc15 compile time error, and to
  still allow build on Leap 15.6
* Fri Feb 28 2025 Marius Grossu <marius.grossu@suse.com>
- Update to version 0.18.0:
  * drop combining compile time option
  * bump mozjs dependency to 128
  * console.assert (and extension console.exit)
  * test option for testing js code
  * added document.scripting_sleep_on_error option #319
  * skip hidden elements #341
  * fix linking -lexecinfo #337
  * Serbian translation update
  * Polish translation update
  * detect if gettext has _nl_msg_cat_cntr #325
  * added reopen-last-closed-tab action #309
  * added options for memory limits of Spidermonkey and QuickJS
  * gemini input #121
  * compilation fixes
  * redirect also for 308 #343
  * ignore HUBBUB_UNKNOWN #344
- Add move_ruby_headers.patch: Moved the headers to a ruby.c
  (gh#rkd77/elinks#370)
* Thu Oct 10 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.17.1.1:
  + bump requirements: libCSS to 0.9.2 and libdom to 0.4.2
  + revert "[head] addcrlf". #281
  + main, article and nav elements #282
  + bashism in configure.ac #285
  + eliminate GNUism in sed #305
  + python module imp is deprecated #313
  + fix hooks.py detection #333
  + cast to unsigned char * in inpfield #315
  + fix suspend in session master when fork_on_start #296
  + remove 300ms startup delay and optimize fork_on_start #297
  + missing <sys/cdefs.h> on systems with musl libc #306
- Changes from version 0.17.1:
  + fix for some 32-bit systems and select-only builds
  + fix for gettext in Windows builds
* Tue Sep 10 2024 Gustavo Pichorim Boiko <gboiko@suse.com>
- Fix building on ppc64le (by using lua instead of luajit there)
* Sun Jan 14 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- update to 0.17.0:
  * Avoid division by zero. Refs #276
  * fix for some 32-bit systems and select-only builds
  * configuration files are now saved to ~/.config/elinks/ or
    $XDG_CONFIG_HOME/elinks/ #199
  * User must copy files from ~/.elinks/ to ~/.config/elinks/
    himself or herself
  * HOME_ETC support was dropped, you can set with ELINKS_CONFDIR
  * idn2 in place of idn #206
  * libcss support (a few netsurf's libraries are required).
    Set document.css.libcss = 1 to enable
  * experimental libsixel support (image/*; img2sixel %%s;
    copiousoutput) in ~/.mailcap
  * Must be enabled in a few places in configuration: set
    document.plain.sixel = 1
  * and in terminal options. Do not try it on metered remote
    connections
  * testing libcurl support (explicit FTPS and SFTP among others)
  * To enable set protocol.ftp.use_curl = 1
  * set protocol.http.use_curl = 1 for http/https
  * ui.sessions.postpone_unlink option. Delete temporary files at
    exit instead of immediately after
  * closing viewer #257
  * redefined isspace #249
  * Serbian translation update
  * compilation fixes
- Add pkgconfig(libdom) BuildRequires: fix build to enable js.
- Enable gemini support
- Removed unneeded patches:
  * perl-5.38.patch
  * 0006-elinks-0.16.0-libidn2.patch
* Thu Aug  3 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add perl-5.38.patch: Fix compilation with Perl 5.38
  (gh#rkd77/elinks#243).
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.16.1.1:
  * updated POTFILES
* Mon May  1 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.16.1
  * handle SECTION html element #207
  * allocate more memory for BLOCKQUOTE #214
  * encode A href to terminal codepage and encode bytes with
    highest bit set as %%HEX #221
  * Serbian translation update
  * install doc by default in meson #224
  * tests fixes
* Sun Apr 30 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to rkd77 git version 0.16.0
- Enable javascript with mujs on Tumbleweed (missing libxml++-5.0 on leap)
- Use LuaJIT for lua compiler until someone fix it with standart Lua
- Removed unneeded patches:
  * build-with-new-ruby.patch
- Added the following patches:
  * 0006-elinks-0.16.0-libidn2.patch
* Wed Aug 24 2022 Andreas Schwab <schwab@suse.de>
- Makefile is not parallel-safe
* Mon Jun 13 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Require perl in the same version as we built against: elinks
  links to libperl.so, which changes location based on perl
  version. The relevant path in encoded as RUNPATH into the binary
  (boo#1199945).
* Tue Jul 23 2019 sbrabec@suse.com
- Update to 20190723 snapshot of version 0.13:
  * no changes
- Use pre-version tag, as the current snapshot is a pre-release.
- Remove volatile URL from Source0.
- Compile without strict aliasing to prevent breakage with new gcc.
* Mon Apr  1 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 0.13
  * parse_header: document parameters and return value
  * doxygen: Fix link to bookmark::url
  * use draw_text for titles
  * iconv: Bail out of the loop when an illegal sequence of bytes
    occur
  * Add support for the CSS list-style-type property
  * configure.in: use PKG_CONFIG
  * Fixed problem of converting more than 256 chars
  * mem_free_if where aplicable
  * ssl: Make RAND_egd optional
  * Better handling of content-disposition
  * Compilation fix for OpenSSL-1.1
  * display lua hooks errors
  * brotli code updated
  * Use blacklist to skip verification of certificates
  * various code cleanup
  * -VERS-SSL3.0 in gnutls to avoid SSL error.
  * 1024: Verify server certificate hostname with OpenSSL (bsc#1082814)
- Removed unneeded patches:
  * elinks-0.12_pre5-compilation-fix.patch
  * use_lua-5.1.patch
  * build.with-openssl-1_1.patch
- Renamed patch:
  * build-with-ruby-1.9.patch -> build-with-new-ruby.patch
* Thu Dec 28 2017 crrodriguez@opensuse.org
- build.with-openssl-1_1.patch: fix build with openssl 1.1.
* Tue Jun 14 2016 adam.majer@suse.de
- Add %%perl_requires to be certain that package rebuilds when
  perl is updated. This is causing elinks not to be rebuilt with
  factory and it can't find current libperl.so. See bnc#984661
  for details.
* Tue Apr 26 2016 sleep_walker@opensuse.org
- disable JS support until someone fix it
- refresh patches
- fix indentation
* Mon Dec 24 2012 tchvatal@suse.com
- Version bump to 0.12_pre6.
  * Remove upstream included js186 patches.
  * Add new patch for ruby1.9 build.
* Sun Jun 10 2012 asterios.dramis@gmail.com
- Updated License to GPL-2.0.
- Added the following patches:
  * elinks-0.12_pre5-js185-1-heartbeat.patch,
    elinks-0.12_pre5-js185-2-up.patch,
    elinks-0.12_pre5-js185-3-histback.patch: Support for new js-1.8.5
  * elinks-0.12_pre5-compilation-fix.patch: Fix compilation with gc
  * use_lua-5.1.patch: Support for lua-5.1
- Added automake in BuildRequires in order to regenerate the build system
  because of patches modifying configure.in.
- Corrected gmp-devel build dependency to gpm-devel.
- Removed guile-devel build dependency (wasn't used anyway and the support is
  expiremental).
- Removed python-devel build dependency since the support is expiremental.
- Use ruby-devel only in openSUSE <= 12.1 since it fails with ruby 1.9 from
  Factory.
- Added the following build dependencies that can be used by the package:
  gc-devel (for openSUSE > 11.4), js-devel (for openSUSE > 11.4), krb5-devel,
  lua*-devel, pkg-config and tre-devel.
- Make the package provide "web_browser", similar to other web browser
  packages.
- Removed build time references so build-compare can do its work.
- Enabled the following build options: true-color and fastmem.
- Install documentation only for the scripting languages that are compiled.
* Fri Jun 10 2011 lijewski.stefan@gmail.com
- fix sysconfdir to /etc/elinks
* Tue Apr 26 2011 puzel@novell.com
- use spec-cleaner
* Wed Jan 27 2010 puzel@novell.com
- update to 0.12pre5
* Wed Jan 27 2010 puzel@novell.com
- prepare for Contrib (disabled lua and js functionality for now)
* Mon Sep 15 2008 mrueckert@suse.de
- update to 0.12pre1
* Wed Apr 18 2007 mrueckert@suse.de
- build with stack protector if possible
* Wed Apr 18 2007 mrueckert@suse.de
- fix building with javascript
* Wed Apr 18 2007 mrueckert@suse.de
- added javascript support
* Mon Apr 16 2007 mrueckert@suse.de
- update to version 0.11.3:
  important bug and security fixes
- remove the python patches
* Fri Dec  1 2006 mrueckert@suse.de
- disable lua until i fixed the patch
* Mon Nov 20 2006 mrueckert@suse.de
- update to version 0.11.2:
  fixes CVE-2006-5925
* Fri Mar 10 2006 mrueckert@suse.de
- update to version 0.11.1
* Fri Dec 23 2005 mrueckert@suse.de
- update to version 0.11rc0
* Mon Sep 26 2005 mrueckert@suse.de
- Update to version 0.10.6
